@@ -10,7 +10,7 @@ if __name__ == '__main__':
    # If the plugins are not already installed, we'll just ignore
    # them and generate the narrative documentation.
    try:
-      from gamera.toolkits.ocr.plugins import clear
+      from gamera.toolkits.ocr.plugins import bbox_merging_mcmillan
    except ImportError:
       print "WARNING:"
       print "This `ocr` toolkit must be installed before generating"
@@ -27,6 +27,9 @@ if __name__ == '__main__':
 			  ("gamera.toolkits.ocr.classes",
                            "Page",
                            "__init__ segment page_to_lines order_lines lines_to_chars chars_to_words show_lines show_glyphs show_words"),
+			  ("gamera.toolkits.ocr.classes",
+                           "hocrPage",
+                           "__init__"),
 			  ("gamera.toolkits.ocr.classes",
                            "ClassifyCCs",
                            "__init__ __call__")],
