@@ -9,7 +9,7 @@ and may be omitted if you are not concerned with that.
 
 from gamera import toolkit
 import plugins
-import wx
+#import wx
 
 
 # You can inherit from toolkit.CustomMenu to create a menu
