@@ -55,7 +55,7 @@ When *classname* is not listed in *extra_chars_dict*, it must correspond
 to a `standard unicode character name`_,
 as in the examples of the following table:
 
-.. _`standard unicode character names`: http://www.unicode.org/charts/
+.. _`standard unicode character name`: http://www.unicode.org/charts/
 
 
 +-----------+----------------------------+----------------------------+
